import Link from "next/link";
import { notFound, redirect } from "next/navigation";
import type { ExtendedAccessToken, ExtendedClient } from "@/types";
import { ArrowLeft } from "lucide-react";

import { getAuthorizationsByClientId } from "@/lib/dto/authorization";
import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { AuthorizationStatusToggle } from "@/components/admin/authorization-status-toggle";
import { ClientStatusToggle } from "@/components/admin/client-status-toggle";

async function getClientDetails(id: string) {
  const client = await prisma.client.findUnique({
    where: { id },
    include: {
      user: {
        select: {
          username: true,
          email: true,
        },
      },
      accessTokens: {
        where: {
          expiresAt: {
            gt: new Date(),
          },
        },
        include: {
          user: {
            select: {
              username: true,
            },
          },
        },
      },
    },
  });

  if (!client) {
    return null;
  }

  // 获取授权用户列表
  const authorizations = await getAuthorizationsByClientId(id);

  // 获取最近30天的授权统计
  const thirtyDaysAgo = new Date();
  thirtyDaysAgo.setDate(thirtyDaysAgo.getDate() - 30);

  const authCount = await prisma.accessToken.count({
    where: {
      clientId: id,
      expiresAt: {
        gte: thirtyDaysAgo,
      },
    },
  });

  return {
    ...client,
    authCount,
    authorizations,
  } as ExtendedClient & {
    authorizations: Awaited<ReturnType<typeof getAuthorizationsByClientId>>;
  };
}

export default async function ClientDetailsPage({
  params,
}: {
  params: { id: string };
}) {
  const user = await getCurrentUser();
  if (!user || user.role !== "ADMIN") {
    redirect("/dashboard");
  }

  const client = await getClientDetails(params.id);
  if (!client) {
    notFound();
  }

  return (
    <div className="mx-auto max-w-7xl px-4 py-8 sm:px-6 lg:px-8">
      <div className="mb-8 flex items-center justify-between">
        <div className="flex items-center gap-4">
          <Link href="/admin/clients">
            <Button variant="outline" size="icon">
              <ArrowLeft className="h-4 w-4" />
            </Button>
          </Link>
          <h1 className="text-2xl font-bold">{client.name}</h1>
          <ClientStatusToggle client={client} />
        </div>
      </div>

      <div className="grid gap-6 md:grid-cols-2">
        <Card>
          <CardHeader>
            <CardTitle>应用信息</CardTitle>
            <CardDescription>应用的基本信息</CardDescription>
          </CardHeader>
          <CardContent>
            <dl className="space-y-4">
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  Client ID
                </dt>
                <dd className="mt-1 font-mono">{client.clientId}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  Client Secret
                </dt>
                <dd className="mt-1 font-mono">{client.clientSecret}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  回调地址
                </dt>
                <dd className="mt-1">{client.redirectUri}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  应用主页
                </dt>
                <dd className="mt-1">
                  {client.home ? (
                    <a
                      href={client.home}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-primary hover:underline"
                    >
                      {client.home}
                    </a>
                  ) : (
                    "-"
                  )}
                </dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  创建者
                </dt>
                <dd className="mt-1">{client.user.username}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  创建时间
                </dt>
                <dd className="mt-1">
                  {new Date(client.createdAt).toLocaleString()}
                </dd>
              </div>
            </dl>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>使用统计</CardTitle>
            <CardDescription>应用的使用情况统计</CardDescription>
          </CardHeader>
          <CardContent>
            <dl className="space-y-4">
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  最近30天授权次数
                </dt>
                <dd className="mt-1 text-3xl font-bold">{client.authCount}</dd>
              </div>
              <div>
                <dt className="text-sm font-medium text-muted-foreground">
                  当前活跃令牌
                </dt>
                <dd className="mt-1 text-3xl font-bold">
                  {client.accessTokens?.length || 0}
                </dd>
              </div>
            </dl>
          </CardContent>
        </Card>

        <Card className="md:col-span-2">
          <CardHeader>
            <CardTitle>授权用户</CardTitle>
            <CardDescription>已授权的用户列表</CardDescription>
          </CardHeader>
          <CardContent>
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>用户名</TableHead>
                  <TableHead>邮箱</TableHead>
                  <TableHead>授权时间</TableHead>
                  <TableHead>最后使用</TableHead>
                  <TableHead>状态</TableHead>
                  <TableHead className="text-right">操作</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {client.authorizations.map((auth) => (
                  <TableRow key={auth.id}>
                    <TableCell>{auth.user.username}</TableCell>
                    <TableCell>{auth.user.email}</TableCell>
                    <TableCell>
                      {new Date(auth.createdAt).toLocaleString()}
                    </TableCell>
                    <TableCell>
                      {auth.lastUsedAt
                        ? new Date(auth.lastUsedAt).toLocaleString()
                        : "从未使用"}
                    </TableCell>
                    <TableCell>
                      <Badge variant={auth.enabled ? "default" : "destructive"}>
                        {auth.enabled ? "已授权" : "已禁用"}
                      </Badge>
                    </TableCell>
                    <TableCell className="text-right">
                      <AuthorizationStatusToggle authorization={auth} />
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </CardContent>
        </Card>
      </div>
    </div>
  );
}
