import Link from "next/link";
import { redirect } from "next/navigation";
import { Activity, AppWindow, FileText, Users } from "lucide-react";

import { prisma } from "@/lib/prisma";
import { getCurrentUser } from "@/lib/session";
import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";

async function getStats() {
  const [userCount, clientCount, activeTokenCount, recentAuthCount] =
    await Promise.all([
      prisma.user.count(),
      prisma.client.count(),
      prisma.accessToken.count({
        where: {
          expiresAt: {
            gt: new Date(),
          },
        },
      }),
      prisma.authorization.count({
        where: {
          createdAt: {
            gt: new Date(Date.now() - 24 * 60 * 60 * 1000), // 最近24小时
          },
        },
      }),
    ]);

  const recentClients = await prisma.client.findMany({
    include: {
      user: {
        select: {
          username: true,
          email: true,
        },
      },
    },
    orderBy: {
      createdAt: "desc",
    },
    take: 5,
  });

  return {
    userCount,
    clientCount,
    activeTokenCount,
    recentAuthCount,
    recentClients,
  };
}

export default async function AdminPage() {
  const user = await getCurrentUser();
  if (!user || user.role !== "ADMIN") {
    redirect("/dashboard");
  }

  const stats = await getStats();

  return (
    <div className="mx-auto max-w-7xl px-4 py-8 sm:px-6 lg:px-8">
      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-4">
        <Card>
          <CardHeader>
            <CardTitle className="flex items-center gap-2">
              <Users className="h-5 w-5" />
              用户管理
            </CardTitle>
            <CardDescription>管理系统中的用户账号</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <p className="text-3xl font-bold">{stats.userCount}</p>
            <Link href="/admin/users">
              <Button className="w-full">查看用户</Button>
            </Link>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle className="flex items-center gap-2">
              <AppWindow className="h-5 w-5" />
              应用管理
            </CardTitle>
            <CardDescription>管理系统中的应用</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <p className="text-3xl font-bold">{stats.clientCount}</p>
            <Link href="/admin/clients">
              <Button className="w-full">查看应用</Button>
            </Link>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle className="flex items-center gap-2">
              <Activity className="h-5 w-5" />
              系统状态
            </CardTitle>
            <CardDescription>查看系统运行状态</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <p className="text-3xl font-bold">{stats.activeTokenCount}</p>
            <p className="text-sm text-muted-foreground">活跃访问令牌数</p>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle className="flex items-center gap-2">
              <FileText className="h-5 w-5" />
              系统日志
            </CardTitle>
            <CardDescription>查看系统日志记录</CardDescription>
          </CardHeader>
          <CardContent className="space-y-4">
            <p className="text-3xl font-bold">{stats.recentAuthCount}</p>
            <div className="flex items-center justify-between">
              <p className="text-sm text-muted-foreground">
                24小时内新增授权数
              </p>
              <Link href="/admin/logs">
                <Button variant="outline" size="sm">
                  查看日志
                </Button>
              </Link>
            </div>
          </CardContent>
        </Card>
      </div>

      <div className="mt-8 grid gap-4 md:grid-cols-2">
        <Card>
          <CardHeader>
            <CardTitle>最近创建的应用</CardTitle>
            <CardDescription>显示最近创建的 5 个应用</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              {stats.recentClients.map((client) => (
                <div
                  key={client.id}
                  className="flex items-center justify-between border-b pb-4 last:border-0 last:pb-0"
                >
                  <div className="space-y-1">
                    <p className="font-medium">{client.name}</p>
                    <p className="text-sm text-muted-foreground">
                      由 {client.user.username} 创建于{" "}
                      {new Date(client.createdAt).toLocaleString()}
                    </p>
                  </div>
                  <Link href={`/admin/clients/${client.id}`}>
                    <Button variant="outline" size="sm">
                      查看
                    </Button>
                  </Link>
                </div>
              ))}
            </div>
          </CardContent>
        </Card>

        <Card>
          <CardHeader>
            <CardTitle>系统信息</CardTitle>
            <CardDescription>显示系统运行状态信息</CardDescription>
          </CardHeader>
          <CardContent>
            <div className="space-y-4">
              <div className="flex items-center justify-between">
                <p className="text-sm font-medium">Node.js 版本</p>
                <p className="text-sm text-muted-foreground">
                  {process.version}
                </p>
              </div>
              <div className="flex items-center justify-between">
                <p className="text-sm font-medium">系统平台</p>
                <p className="text-sm text-muted-foreground">
                  {process.platform}
                </p>
              </div>
              <div className="flex items-center justify-between">
                <p className="text-sm font-medium">系统架构</p>
                <p className="text-sm text-muted-foreground">{process.arch}</p>
              </div>
              <div className="flex items-center justify-between">
                <p className="text-sm font-medium">进程ID</p>
                <p className="text-sm text-muted-foreground">{process.pid}</p>
              </div>
              <div className="flex items-center justify-between">
                <p className="text-sm font-medium">运行时长</p>
                <p className="text-sm text-muted-foreground">
                  {Math.floor(process.uptime())} 秒
                </p>
              </div>
            </div>
          </CardContent>
        </Card>
      </div>
    </div>
  );
}
